@@ -1,7 +1,8 @@
 from unit_parse.logger import logger
 from unit_parse.config import config, Unit, Quantity, Q, U
 from unit_parse.main import parser
+from unit_parse.reduce_quantities import reduce_quantities
 
 __all__ = [
-     "Unit", "U", "Q", "Quantity", "parser", "logger"
+     "Unit", "U", "Q", "Quantity", "parser", "logger", "reduce_quantities"
 ]
